@@ -274,7 +274,7 @@ def get_product_latest_components_query(ctx, product_stream_name, ofuri):
     name="component-manifest",
     help="Get Component manifest.",
 )
-@click.option("--uuid", "Component_uuid")
+@click.option("--uuid", "component_uuid")
 @click.option("--purl", help="Component Purl (must be quoted).")
 @click.option(
     "--spdx-json",
@@ -294,7 +294,7 @@ def retrieve_component_manifest(ctx, component_uuid, purl, spdx_json_format):
         ctx.obj["FORMAT"] = "json"
     cond = {}
     if component_uuid:
-        cond["component_uuid"] = component_uuid
+        cond["uuid"] = component_uuid
     if purl:
         cond["purl"] = purl
     ctx.invoke(get_component_manifest, **cond)
